@@ -1,12 +1,8 @@
 # Constant urls for data retrieval
 cdec_urls <- list(
-
-  download_shef = "http://cdec.water.ca.gov/cgi-progs/querySHEF?station_id={STATION}&sensor_num={SENSOR}&dur_code={DURCODE}&start_date={STARTDATE}&end_date={ENDDATE}&data_wish=Download+SHEF+Data+Now",
   wy_forecast = "http://cdec.water.ca.gov/cgi-progs/iodir/wsi",
   station_hydro_area = "http://cdec.water.ca.gov/cgi-progs/staMeta?station_id=STATION",
-  station_metadata = "https://cdec.water.ca.gov/cgi-progs/staSearch?sta_chk=on&sta=STATION",
-  datasets = "https://cdec.water.ca.gov/cgi-progs/querySHEF",
-  rating_tables = "http://cdec.water.ca.gov/rtables/{STATION}.html",
+  station_metadata = "http://cdec.water.ca.gov/dynamicapp/staMeta?station_id=STATION",
   wy_index = "http://cdec.water.ca.gov/cgi-progs/iodir/wsi",
   stations = "http://cdec.water.ca.gov/dynamicapp/staMeta?station_id=STATION"
 )
