@@ -1,7 +1,7 @@
 #' Search CDEC Stations
 #'
 #' Search the stations in the CDEC system using the CDEC Station Search
-#' service \href{https://cdec.water.ca.gov/cgi-progs/staSearch}{here}. Combinations
+#' service \href{https://cdec.water.ca.gov/dynamicapp/staSearch}{here}. Combinations
 #' of these parameters can be supplied to refine or be left out to generalize, at least
 #' one must be supplied.
 #'
@@ -10,11 +10,18 @@
 #' @param river_basin string search stations in supplied basin
 #' @param hydro_area string search stations in supplied hydrological area
 #' @param county string search stations in supplied county
+#' @return data frame with queried stations as rows and
+#' columns describing the \code{station_id}, \code{name}, \code{river_basin}, \code{county}, \code{longitude},
+#' \code{latitude}, \code{elevation}, \code{operator}, and \code{state}
 #' @examples
 #' # cdec_stations() can be used to find locations within an area of interest
+#' \dontrun{
 #' cdec_stations(county = "alameda")
+#' }
 #' # or it can be used to get metadata attributes for a location
+#' \dontrun{
 #' cdec_stations(station_id = "ccr")
+#' }
 #' @export
 cdec_stations <- function(station_id=NULL, nearby_city=NULL, river_basin=NULL,
                           hydro_area=NULL, county=NULL) {
@@ -31,12 +38,16 @@ cdec_stations <- function(station_id=NULL, nearby_city=NULL, river_basin=NULL,
                                 county=county)
 
   resp <- tryCatch(
-    httr::GET("https://cdec.water.ca.gov/cgi-progs/staSearch", query = query),
+    httr::GET("https://cdec.water.ca.gov/dynamicapp/staSearch", query = query),
     error = function(e) {
       stop("Could not reach CDEC services", call. = FALSE)
     }
   )
 
+  if (resp$status_code == 404) {
+    stop("Could not reach CDEC services", call. = FALSE)
+  }
+
   html_page <- xml2::read_html(resp$url)
   html_table_node <- rvest::html_node(html_page, "table")
 
@@ -59,16 +70,21 @@ cdec_stations <- function(station_id=NULL, nearby_city=NULL, river_basin=NULL,
 #'
 #' @param .data result of a cdec_stations() call
 #' @param ... named arguments passed into leaflet::addCircleMarkers
+#' @return a leaflet map widget with circle markers at the locations of CDEC stations
 #' @examples
+#' \dontrun{
 #' if (interactive()) {
 #'     cdec_stations(county = "alameda") %>% map_stations(label=~name, popup=~station_id)
 #' }
+#' }
 #' @export
 map_stations <- function(.data, ...) {
-  if (!inherits(.data, "cdec_stations")) {
+  if (!inherits(.data, "tbl_df")) {
     stop(".data does not appear to be a call from cdec_stations()", call. = FALSE)
   }
-
+  if (nrow(.data) == 0) {
+    stop(".data appears to be an empty table, check cdec_station() call")
+  }
   if (!requireNamespace("leaflet", quietly = TRUE)) {
     stop("map_stations() requires leaflet to be installed (map_stations)")
   }
